# aiomessenger

[![travis-ci][travis-image]][travis-url]    [![pypi-version][pypi-image]][pypi-url]    [![codecov][codecov-image]][codecov-url]

[travis-image]: https://travis-ci.org/stegben/aiomessenger.svg?branch=master
[travis-url]: https://travis-ci.org/stegben/aiomessenger

[pypi-image]: https://badge.fury.io/py/aiomessenger.svg
[pypi-url]: https://badge.fury.io/py/aiomessenger

[codecov-image]: https://codecov.io/gh/stegben/aiomessenger/branch/master/graph/badge.svg
[codecov-url]: https://codecov.io/gh/stegben/aiomessenger
